@@ -3,8 +3,8 @@
 
 #include "cheese-enums.h"
 
-/* enumerations from "./libcheese/cheese-widget.h" */
-#include "./libcheese/cheese-widget.h"
+/* enumerations from "/home/david/checkout/gnome/cheese/libcheese/cheese-widget.h" */
+#include "/home/david/checkout/gnome/cheese/libcheese/cheese-widget.h"
 GType
 cheese_widget_state_get_type (void)
 {
